@@ -26,7 +26,7 @@
 #include <OGRE/Ogre.h>
 #include <cstddef> // CEGUI bugfix.
 #include <CEGUI/CEGUI.h>
-#include <OgreCEGUIRenderer.h>
+#include <CEGUI/RendererModules/Ogre/CEGUIOgreRenderer.h>
 
 #include <psynth/version.hpp>
 #include <psynth/base/timer.hpp>
@@ -42,6 +42,7 @@
 #include "gui3d/task_manager.hpp"
 #include "gui3d/element_manager.hpp"
 #include "gui3d/window_list.hpp"
+#include "gui3d/network_window.hpp"
 #include "gui3d/camera_controller_default.hpp"
 
 class psychosynth_3d : public psynth::psynth_app,
@@ -64,9 +65,8 @@ private:
     Ogre::Camera*        m_camera;
     Ogre::Viewport*      m_viewport;
 	
-    CEGUI::System*            m_gui;
-    CEGUI::OgreCEGUIRenderer* m_ceguirender;
-
+    CEGUI::System*       m_gui;
+    
     default_selector_populator m_populator;
     input_manager*      m_inputmgr;
     cegui_injecter*     m_guiinput;
@@ -77,8 +77,7 @@ private:
     psynth::base::timer m_timer;
 
 #ifdef PSYNTH_HAVE_OSC
-    psynth::osc_client* m_oscclient;
-    psynth::osc_server* m_oscserver;
+    network_window*     m_netwindow;
 #endif
     
     bool   m_must_quit;
