@@ -46,7 +46,7 @@ selector_window::category::button::button (const std::string& name,
     m_window->setSize ( UVector2(CEGUI::UDim(0, BUT_WIDTH),
                                  CEGUI::UDim(0, BUT_HEIGHT)));
 
-    m_window->setMousePassThroughEnabled (false);
+    //m_window->setMousePassThroughEnabled (false);
     //m_window->setWantsMultiClickEvents(false);
     m_window->setEnabled(true);
     m_window->subscribeEvent(
@@ -131,7 +131,7 @@ CEGUI::FrameWindow* selector_window::create_window ()
     //window->setPosition(UVector2(UDim(0, 10), UDim(0, 10)) );
     //window->setSize    ( UVector2(UDim(1, -20),UDim(0, 100)) );
     window->setPosition( UVector2(UDim(0, 10), UDim(0, 10)) );
-    window->setSize    ( UVector2(UDim(1, -20),UDim(0, 134)) );
+    window->setSize    ( UVector2(UDim(1, -20),UDim(0, 150)) );
     window->setText("Object Selector");
 	
     m_container = wmgr.createWindow("TaharezLook/TabControl", "container_selector");
