@@ -1,5 +1,5 @@
 /**
- *  Time-stamp:  <2009-04-07 19:46:58 raskolnikov>
+ *  Time-stamp:  <2010-10-19 02:03:24 raskolnikov>
  *
  *  @file        task_manager.hpp
  *  @author      Juan Pedro Bolívar Puente <raskolnikov@es.gnu.org>
@@ -90,7 +90,7 @@ public:
 /**
  * @todo separate from singleton_holder
  */
-class task_manager : public psynth::singleton_holder<task_manager>
+class task_manager
 {
     typedef std::list<task*> task_list;
     typedef std::list<task*>::iterator task_iter;
@@ -125,6 +125,8 @@ public:
     }
 };
 
+typedef psynth::base::singleton_holder<task_manager> global_task_manager;
+
 void task::finish ()
 {
     m_is_finished = true;
